/*
 * Copyright 2020 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.vector.app.features.roommemberprofile

import im.vector.app.core.platform.VectorViewEvents

/**
 * Transient events for RoomMemberProfile
 */
sealed class RoomMemberProfileViewEvents : VectorViewEvents {
    data class Loading(val message: CharSequence? = null) : RoomMemberProfileViewEvents()
    data class Failure(val throwable: Throwable) : RoomMemberProfileViewEvents()

    object OnIgnoreActionSuccess : RoomMemberProfileViewEvents()
    object OnSetPowerLevelSuccess : RoomMemberProfileViewEvents()
    object OnInviteActionSuccess : RoomMemberProfileViewEvents()
    object OnKickActionSuccess : RoomMemberProfileViewEvents()
    object OnBanActionSuccess : RoomMemberProfileViewEvents()
    data class ShowPowerLevelValidation(val currentValue: Int, val newValue: Int) : RoomMemberProfileViewEvents()
    data class ShowPowerLevelDemoteWarning(val currentValue: Int, val newValue: Int) : RoomMemberProfileViewEvents()

    data class StartVerification(
            val userId: String,
            val canCrossSign: Boolean
    ) : RoomMemberProfileViewEvents()

    data class ShareRoomMemberProfile(val permalink: String) : RoomMemberProfileViewEvents()
}
